parse_versions_from_feed

Function parse_versions_from_feed 

fn parse_versions_from_feed(xml: &str) -> Vec<Version>
Extract all semver-parseable versions from the <title> elements inside <entry> blocks of an Atom feed.

The feed is generated by abbaye itself and has a predictable structure: each entry’s title appears on its own line as <title>X.Y.Z</title>. The feed-level <title>Abbaye Releases</title> will not parse as semver and is silently ignored.